@@ -6,9 +6,9 @@ from glob import glob
 from typing import List
 
 from PIL import Image, ImageDraw
-from sympy import Point2D
 from tqdm import tqdm
 
+from omrdatasettools.Point2D import Point2D
 from omrdatasettools.ExportPath import ExportPath
 from omrdatasettools.Rectangle import Rectangle
 
