@@ -56,7 +56,7 @@ class OmrDataset(Enum):
     #: The second version of the MUSCIMA++ dataset from https://github.com/OMR-Research/muscima-pp
     MuscimaPlusPlus_V2 = auto()
 
-    #: The measure annotations from the MUSCIMA++ dataset
+    #: A sub-set of the MUSCIMA++ annotations that contains bounding-box annotations for staves, staff measures and system measures. It was semi-automatically constructed from existing annotations and manually verified for correctness. The annotations are available in a plain JSON format as well as in the COCO format.
     MuscimaPlusPlus_MeasureAnnotations = auto()
 
     #: The OpenOMR Symbols dataset from https://sourceforge.net/projects/openomr/, Copyright 2013 by Arnaud F. Desaedeleer under GPL license
@@ -74,6 +74,12 @@ class OmrDataset(Enum):
     #: The DeepScore dataset (version 1) with extended vocabulary from https://tuggeluk.github.io/downloads/, License unspecified.
     DeepScores_V1_Extended = auto()
 
+    #: The Measure Bounding Box Annotation dataset from https://www.audiolabs-erlangen.de/resources/MIR/2019-ISMIR-LBD-Measures, Copyright 2019 by Frank Zalkow, Angel Villar Corrales, TJ Tsai, Vlora Arifi-Müller, and Meinard Müller under CC BY-NC-SA 4.0 license
+    MeasureBoundingBoxAnnotations_v1 = auto()
+
+    #: The second version of the Measure Bounding Box Annotation dataset enhanced with staves, staff measures and the original system measures. The annotations are available in csv, JSON and COCO format.
+    MeasureBoundingBoxAnnotations_v2 = auto()
+
     def get_dataset_download_url(self) -> str:
         """ Returns the url of the selected dataset.
             Example usage: OmrDataset.Fornes.get_dataset_download_url() """
@@ -136,7 +142,12 @@ class OmrDataset(Enum):
             "Rebelo1": "https://github.com/apacha/OMR-Datasets/releases/download/datasets/Rebelo-Music-Symbol-Dataset1.zip",
             "Rebelo2": "https://github.com/apacha/OMR-Datasets/releases/download/datasets/Rebelo-Music-Symbol-Dataset2.zip",
 
-            "DeepScores_V1_Extended": "https://repository.cloudlab.zhaw.ch/artifactory/deepscores/ds_extended.zip"
+            "DeepScores_V1_Extended": "https://repository.cloudlab.zhaw.ch/artifactory/deepscores/ds_extended.zip",
+
+            # Official URL: https://www.audiolabs-erlangen.de/resources/MIR/2019-ISMIR-LBD-Measures
+            "MeasureBoundingBoxAnnotations_v1": "https://github.com/apacha/OMR-Datasets/releases/download/datasets/MeasureBoundingBoxAnnotations_v1.zip",
+
+            "MeasureBoundingBoxAnnotations_v2": "https://github.com/apacha/OMR-Datasets/releases/download/datasets/MeasureBoundingBoxAnnotations_v2.zip"
         }
 
     def dataset_file_names(self) -> Dict[str, str]:
@@ -161,5 +172,7 @@ class OmrDataset(Enum):
             "Printed": "PrintedMusicSymbolsDataset.zip",
             "Rebelo1": "Rebelo-Music-Symbol-Dataset1.zip",
             "Rebelo2": "Rebelo-Music-Symbol-Dataset2.zip",
-            "DeepScores_V1_Extended": "ds_extended.zip"
+            "DeepScores_V1_Extended": "ds_extended.zip",
+            "MeasureBoundingBoxAnnotations_v1": "MeasureBoundingBoxAnnotations_v1.zip",
+            "MeasureBoundingBoxAnnotations_v2": "MeasureBoundingBoxAnnotations_v2.zip"
         }
